@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2007 Bill Wilson
+|  Copyright (C) 1999-2009 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -17,6 +17,18 @@
 |
 |  You should have received a copy of the GNU General Public License
 |  along with this program. If not, see http://www.gnu.org/licenses/
+|
+|
+|  Additional permission under GNU GPL version 3 section 7
+|
+|  If you modify this program, or any covered work, by linking or
+|  combining it with the OpenSSL project's OpenSSL library (or a
+|  modified version of that library), containing parts covered by
+|  the terms of the OpenSSL or SSLeay licenses, you are granted
+|  additional permission to convey the resulting work.
+|  Corresponding Source for a non-source form of such a combination
+|  shall include the source code for the parts of OpenSSL used as well
+|  as that of the covered work.
 */
 
 
@@ -25,7 +37,8 @@
 
 #if defined(HAVE_CONFIG_H)
 #include "config.h"
-#endif  
+#endif
+#include "log.h"
 
 #if !defined(WIN32)
 #include <sys/param.h>
@@ -84,7 +97,7 @@
 #	define gettext(String) (String)
 #	define dgettext(Domain,String) (String)
 #	define dcgettext(Domain,String,Type) (String)
-#	define bindtextdomain(Domain,Directory) (Domain) 
+#	define bindtextdomain(Domain,Directory) (Domain)
 #endif	/* ENABLE_NLS */
 
 
@@ -94,7 +107,7 @@
 */
 #define	GKRELLM_VERSION_MAJOR	2
 #define	GKRELLM_VERSION_MINOR	3
-#define	GKRELLM_VERSION_REV		1
+#define	GKRELLM_VERSION_REV		4
 #define	GKRELLM_EXTRAVERSION	""
 
 #define GKRELLM_CHECK_VERSION(major,minor,rev)    \
@@ -269,7 +282,7 @@ typedef struct
 	GdkBitmap	*stencil;
 	gint		y_src;		/* Offset into pixmap if a vertical stack	*/
 	gint		w, h;		/* Size of the decal						*/
-	gint		x, y;		/* Position of decal in a drawable			*/	
+	gint		x, y;		/* Position of decal in a drawable			*/
 	gshort		flags,
 				state;
 	gint		value;		/* Index into stack, text value, etc	*/
@@ -1050,13 +1063,13 @@ typedef struct _GkrellmMonitor
 	void		(*save_user_config)(FILE *);
 	void		(*load_user_config)(gchar *);
 	gchar		*config_keyword;
-	
+
 	void		(*undef2)(void);
 	void		(*undef1)(void);
 	GkrellmMonprivate *privat;
 
 	gint		insert_before_id;		/* If plugin, insert before this mon*/
-	
+
 	void		*handle;				/* If monitor is a plugin.	*/
 	gchar		*path;					/* 	"						*/
 	}
